from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Calibration:
	"""Calibration commands group definition. 26 total commands, 7 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("calibration", core, parent)

	@property
	def current(self):
		"""current commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_current'):
			from .Current import Current
			self._current = Current(self._core, self._cmd_group)
		return self._current

	@property
	def voltage(self):
		"""voltage commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_voltage'):
			from .Voltage import Voltage
			self._voltage = Voltage(self._core, self._cmd_group)
		return self._voltage

	@property
	def end(self):
		"""end commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_end'):
			from .End import End
			self._end = End(self._core, self._cmd_group)
		return self._end

	@property
	def cancel(self):
		"""cancel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cancel'):
			from .Cancel import Cancel
			self._cancel = Cancel(self._core, self._cmd_group)
		return self._cancel

	@property
	def ainput(self):
		"""ainput commands group. 5 Sub-classes, 4 commands."""
		if not hasattr(self, '_ainput'):
			from .Ainput import Ainput
			self._ainput = Ainput(self._core, self._cmd_group)
		return self._ainput

	@property
	def point(self):
		"""point commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_point'):
			from .Point import Point
			self._point = Point(self._core, self._cmd_group)
		return self._point

	@property
	def self(self):
		"""self commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_self'):
			from .Self import Self
			self._self = Self(self._core, self._cmd_group)
		return self._self

	# noinspection PyTypeChecker
	class DateStruct(StructBase):  # From ReadStructDefinition CmdPropertyTemplate.xml
		"""Structure for reading output parameters. Fields: \n
			- Arg_0: float: No parameter help available
			- Arg_1: float: No parameter help available
			- Arg_2: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Arg_0'),
			ArgStruct.scalar_float('Arg_1'),
			ArgStruct.scalar_float('Arg_2')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Arg_0: float = None
			self.Arg_1: float = None
			self.Arg_2: float = None

	def get_date(self) -> DateStruct:
		"""SCPI: CALibration:DATE \n
		Snippet: value: DateStruct = driver.calibration.get_date() \n
		Returns the channel adjustment date. \n
			:return: structure: for return value, see the help for DateStruct structure arguments.
		"""
		return self._core.io.query_struct('CALibration:DATE?', self.__class__.DateStruct())

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.CalibrationType:
		"""SCPI: CALibration:TYPE \n
		Snippet: value: enums.CalibrationType = driver.calibration.get_type_py() \n
		No command help available \n
			:return: arg_0: (enum or string) No help available
		"""
		response = self._core.io.query_str('CALibration:TYPE?')
		return Conversions.str_to_scalar_enum_ext(response, enums.CalibrationType)

	def set_type_py(self, arg_0: enums.CalibrationType) -> None:
		"""SCPI: CALibration:TYPE \n
		Snippet: driver.calibration.set_type_py(arg_0 = enums.CalibrationType.CURR) \n
		No command help available \n
			:param arg_0: (enum or string) No help available
		"""
		param = Conversions.enum_ext_scalar_to_str(arg_0, enums.CalibrationType)
		self._core.io.write(f'CALibration:TYPE {param}')

	def get_value(self) -> float:
		"""SCPI: CALibration:VALue \n
		Snippet: value: float = driver.calibration.get_value() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('CALibration:VALue?')
		return Conversions.str_to_float(response)

	def set_value(self, arg_0: float) -> None:
		"""SCPI: CALibration:VALue \n
		Snippet: driver.calibration.set_value(arg_0 = 1.0) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'CALibration:VALue {param}')

	def get_user(self) -> bool:
		"""SCPI: CALibration:USER \n
		Snippet: value: bool = driver.calibration.get_user() \n
		Starts the channel adjustment process. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('CALibration:USER?')
		return Conversions.str_to_bool(response)

	def set_user(self, arg_0: bool) -> None:
		"""SCPI: CALibration:USER \n
		Snippet: driver.calibration.set_user(arg_0 = False) \n
		Starts the channel adjustment process. \n
			:param arg_0: No help available
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'CALibration:USER {param}')

	def save(self) -> None:
		"""SCPI: CALibration:SAVE \n
		Snippet: driver.calibration.save() \n
		Saves the channel adjustment. \n
		"""
		self._core.io.write(f'CALibration:SAVE')

	def save_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CALibration:SAVE \n
		Snippet: driver.calibration.save_with_opc() \n
		Saves the channel adjustment. \n
		Same as save, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALibration:SAVE', opc_timeout_ms)

	def get_temperature(self) -> float:
		"""SCPI: CALibration:TEMPerature \n
		Snippet: value: float = driver.calibration.get_temperature() \n
		Returns the temperature of selected channel. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('CALibration:TEMPerature?')
		return Conversions.str_to_float(response)

	def get_count(self) -> float:
		"""SCPI: CALibration:COUNt \n
		Snippet: value: float = driver.calibration.get_count() \n
		Queries the number of counts channel adjustment performed successfully. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('CALibration:COUNt?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Points:
	"""Points commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("points", core, parent)

	def get(self, arg_0: str) -> int:
		"""SCPI: DATA:POINts \n
		Snippet: value: int = driver.data.points.get(arg_0 = r1) \n
		Queries the number of measurements from the selected logging file. If manual trigger mode (trigger via TRIG function) is
		used, the logging function has to be activated. Without activating the logging function in the manual trigger mode, the
		instrument is not able to save a logging file internally or on the USB stick. \n
			:param arg_0: Filepath of the logging file data.
			:return: result: No help available"""
		param = Conversions.value_to_str(arg_0)
		response = self._core.io.query_str(f'DATA:POINts? {param}')
		return Conversions.str_to_int(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Output:
	"""Output commands group definition. 13 total commands, 6 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRate
			self._symbolRate = SymbolRate(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def triggered(self):
		"""triggered commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_triggered'):
			from .Triggered import Triggered
			self._triggered = Triggered(self._core, self._cmd_group)
		return self._triggered

	@property
	def delay(self):
		"""delay commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_delay'):
			from .Delay import Delay
			self._delay = Delay(self._core, self._cmd_group)
		return self._delay

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import Mode
			self._mode = Mode(self._core, self._cmd_group)
		return self._mode

	@property
	def general(self):
		"""general commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_general'):
			from .General import General
			self._general = General(self._core, self._cmd_group)
		return self._general

	@property
	def impedance(self):
		"""impedance commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_impedance'):
			from .Impedance import Impedance
			self._impedance = Impedance(self._core, self._cmd_group)
		return self._impedance

	def get_ft_response(self) -> bool:
		"""SCPI: OUTPut:FTResponse \n
		Snippet: value: bool = driver.output.get_ft_response() \n
		Sets or queries the fast transient response state. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str_with_opc('OUTPut:FTResponse?')
		return Conversions.str_to_bool(response)

	def set_ft_response(self, arg_0: bool) -> None:
		"""SCPI: OUTPut:FTResponse \n
		Snippet: driver.output.set_ft_response(arg_0 = False) \n
		Sets or queries the fast transient response state. \n
			:param arg_0: No help available
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:FTResponse {param}')

	def get_state(self) -> bool:
		"""SCPI: OUTPut[:STATe] \n
		Snippet: value: bool = driver.output.get_state() \n
		Sets or queries the output state of the previous selected channels. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str_with_opc('OUTPut:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: OUTPut[:STATe] \n
		Snippet: driver.output.set_state(arg_0 = False) \n
		Sets or queries the output state of the previous selected channels. \n
			:param arg_0:
				- 0: Switches off previous selected channels.
				- 1: Switches on previous selected channels."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:STATe {param}')

	def get_select(self) -> bool:
		"""SCPI: OUTPut:SELect \n
		Snippet: value: bool = driver.output.get_select() \n
		Sets or queries the output state of selected channel. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str_with_opc('OUTPut:SELect?')
		return Conversions.str_to_bool(response)

	def set_select(self, arg_0: bool) -> None:
		"""SCPI: OUTPut:SELect \n
		Snippet: driver.output.set_select(arg_0 = False) \n
		Sets or queries the output state of selected channel. \n
			:param arg_0:
				- 0: Deactivates the selected channel.
				- 1: Activates the selected channel."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:SELect {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 5 total commands, 0 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def get_max(self) -> float:
		"""SCPI: MEASure[:SCALar]:POWer:MAX \n
		Snippet: value: float = driver.measure.scalar.power.get_max() \n
		Queries the maximum measured output power. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:POWer:MAX?')
		return Conversions.str_to_float(response)

	def get_avg(self) -> float:
		"""SCPI: MEASure[:SCALar]:POWer:AVG \n
		Snippet: value: float = driver.measure.scalar.power.get_avg() \n
		Queries the average measured output power. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:POWer:AVG?')
		return Conversions.str_to_float(response)

	def get_min(self) -> float:
		"""SCPI: MEASure[:SCALar]:POWer:MIN \n
		Snippet: value: float = driver.measure.scalar.power.get_min() \n
		Queries the minimum measured output power. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:POWer:MIN?')
		return Conversions.str_to_float(response)

	def get_statistic(self) -> float:
		"""SCPI: MEASure[:SCALar]:POWer:STATistic \n
		Snippet: value: float = driver.measure.scalar.power.get_statistic() \n
		Queries the power statistics of the selected channel. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:POWer:STATistic?')
		return Conversions.str_to_float(response)

	def get_value(self) -> float:
		"""SCPI: MEASure[:SCALar]:POWer \n
		Snippet: value: float = driver.measure.scalar.power.get_value() \n
		Queries the currently emitted power of the selected channel \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:POWer?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Omode:
	"""Omode commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("omode", core, parent)

	@property
	def channel(self):
		"""channel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_channel'):
			from .Channel import Channel
			self._channel = Channel(self._core, self._cmd_group)
		return self._channel

	def set(self, arg_0: enums.TriggerOperMode) -> None:
		"""SCPI: TRIGger[:SEQuence][:IMMediate]:SOURce:OMODe \n
		Snippet: driver.trigger.sequence.immediate.source.omode.set(arg_0 = enums.TriggerOperMode.CC) \n
		Sets or queries the operation mode to trigger on for trigger source 'operation mode' See Figure 'Overview of trigger IO
		system'. \n
			:param arg_0: CC | CV | CR | SINK | PROTection CC If respective channel operation mode is detected in CC mode, corresponding trigger-out parameters are triggered. CV If respective channel operation mode is detected in CV mode, corresponding trigger-out parameters are triggered. CR If respective channel operation mode is detected in CR mode, corresponding trigger-out parameters are triggered. SINK If respective channel operation mode is detected in sink mode, corresponding trigger-out parameters are triggered. PROTection If respective channel operation mode is detected in protection mode (OVP, OCP, OPP OTP) , corresponding trigger-out parameters are triggered.
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.TriggerOperMode)
		self._core.io.write(f'TRIGger:SEQuence:IMMediate:SOURce:OMODe {param}')

	# noinspection PyTypeChecker
	def get(self, arg_0: enums.TriggerOperMode) -> enums.TriggerOperMode:
		"""SCPI: TRIGger[:SEQuence][:IMMediate]:SOURce:OMODe \n
		Snippet: value: enums.TriggerOperMode = driver.trigger.sequence.immediate.source.omode.get(arg_0 = enums.TriggerOperMode.CC) \n
		Sets or queries the operation mode to trigger on for trigger source 'operation mode' See Figure 'Overview of trigger IO
		system'. \n
			:param arg_0: CC | CV | CR | SINK | PROTection CC If respective channel operation mode is detected in CC mode, corresponding trigger-out parameters are triggered. CV If respective channel operation mode is detected in CV mode, corresponding trigger-out parameters are triggered. CR If respective channel operation mode is detected in CR mode, corresponding trigger-out parameters are triggered. SINK If respective channel operation mode is detected in sink mode, corresponding trigger-out parameters are triggered. PROTection If respective channel operation mode is detected in protection mode (OVP, OCP, OPP OTP) , corresponding trigger-out parameters are triggered.
			:return: arg_0: CC | CV | CR | SINK | PROTection CC If respective channel operation mode is detected in CC mode, corresponding trigger-out parameters are triggered. CV If respective channel operation mode is detected in CV mode, corresponding trigger-out parameters are triggered. CR If respective channel operation mode is detected in CR mode, corresponding trigger-out parameters are triggered. SINK If respective channel operation mode is detected in sink mode, corresponding trigger-out parameters are triggered. PROTection If respective channel operation mode is detected in protection mode (OVP, OCP, OPP OTP) , corresponding trigger-out parameters are triggered."""
		param = Conversions.enum_scalar_to_str(arg_0, enums.TriggerOperMode)
		response = self._core.io.query_str(f'TRIGger:SEQuence:IMMediate:SOURce:OMODe? {param}')
		return Conversions.str_to_scalar_enum(response, enums.TriggerOperMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ainput:
	"""Ainput commands group definition. 3 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ainput", core, parent)

	@property
	def triggered(self):
		"""triggered commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_triggered'):
			from .Triggered import Triggered
			self._triggered = Triggered(self._core, self._cmd_group)
		return self._triggered

	def get_state(self) -> bool:
		"""SCPI: [SOURce]:VOLTage:AINPut[:STATe] \n
		Snippet: value: bool = driver.source.voltage.ainput.get_state() \n
		Enables or disables the analog input for the selected channel. \n
			:return: arg_0:
				- 1: Analog input for selected channel is enabled.
				- 0: Analog input for selected channel is disabled."""
		response = self._core.io.query_str('SOURce:VOLTage:AINPut:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: [SOURce]:VOLTage:AINPut[:STATe] \n
		Snippet: driver.source.voltage.ainput.set_state(arg_0 = False) \n
		Enables or disables the analog input for the selected channel. \n
			:param arg_0:
				- 1: Analog input for selected channel is enabled.
				- 0: Analog input for selected channel is disabled."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SOURce:VOLTage:AINPut:STATe {param}')

	def get_input_py(self) -> str:
		"""SCPI: [SOURce]:VOLTage:AINPut:INPut \n
		Snippet: value: str = driver.source.voltage.ainput.get_input_py() \n
		Sets or queries the analog input mode. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SOURce:VOLTage:AINPut:INPut?')
		return trim_str_response(response)

	def set_input_py(self, arg_0: str) -> None:
		"""SCPI: [SOURce]:VOLTage:AINPut:INPut \n
		Snippet: driver.source.voltage.ainput.set_input_py(arg_0 = r1) \n
		Sets or queries the analog input mode. \n
			:param arg_0:
				- VOLT: Voltage mode.
				- CURR: Current mode."""
		param = Conversions.value_to_str(arg_0)
		self._core.io.write(f'SOURce:VOLTage:AINPut:INPut {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Types import DataType
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Date:
	"""Date commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("date", core, parent)

	def set(self, year: float, month: float, day: float) -> None:
		"""SCPI: SYSTem:DATE \n
		Snippet: driver.system.date.set(year = 1.0, month = 1.0, day = 1.0) \n
		Sets or queries the system date. \n
			:param year: Sets year of the date.
			:param month: Sets month of the date.
			:param day: Sets day of the date.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('year', year, DataType.Float), ArgSingle('month', month, DataType.Float), ArgSingle('day', day, DataType.Float))
		self._core.io.write(f'SYSTem:DATE {param}'.rstrip())

	# noinspection PyTypeChecker
	class DateStruct(StructBase):
		"""Response structure. Fields: \n
			- Year: float: Sets year of the date.
			- Month: float: Sets month of the date.
			- Day: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Year'),
			ArgStruct.scalar_float('Month'),
			ArgStruct.scalar_float('Day')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Year: float = None
			self.Month: float = None
			self.Day: float = None

	def get(self) -> DateStruct:
		"""SCPI: SYSTem:DATE \n
		Snippet: value: DateStruct = driver.system.date.get() \n
		Sets or queries the system date. \n
			:return: structure: for return value, see the help for DateStruct structure arguments."""
		return self._core.io.query_struct(f'SYSTem:DATE?', self.__class__.DateStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dio:
	"""Dio commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: DigitalIo, default value after init: DigitalIo.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dio", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_digitalIo_get', 'repcap_digitalIo_set', repcap.DigitalIo.Nr1)

	def repcap_digitalIo_set(self, digitalIo: repcap.DigitalIo) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to DigitalIo.Default
		Default value after init: DigitalIo.Nr1"""
		self._cmd_group.set_repcap_enum_value(digitalIo)

	def repcap_digitalIo_get(self) -> repcap.DigitalIo:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, arg_0: enums.TriggerCondition, arg_1: float = None, digitalIo=repcap.DigitalIo.Default) -> None:
		"""SCPI: TRIGger:CONDition:DIO<IO> \n
		Snippet: driver.trigger.condition.dio.set(arg_0 = enums.TriggerCondition.ANINput, arg_1 = 1.0, digitalIo = repcap.DigitalIo.Default) \n
		Sets the trigger condition of the specified Digital I/O line. \n
			:param arg_0: No help available
			:param arg_1: No help available
			:param digitalIo: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Dio')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.Enum, enums.TriggerCondition), ArgSingle('arg_1', arg_1, DataType.Float, None, is_optional=True))
		digitalIo_cmd_val = self._cmd_group.get_repcap_cmd_value(digitalIo, repcap.DigitalIo)
		self._core.io.write(f'TRIGger:CONDition:DIO{digitalIo_cmd_val} {param}'.rstrip())

	# noinspection PyTypeChecker
	class DioStruct(StructBase):
		"""Response structure. Fields: \n
			- Arg_0: enums.TriggerCondition: No parameter help available
			- Arg_1: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Arg_0', enums.TriggerCondition),
			ArgStruct.scalar_float('Arg_1')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Arg_0: enums.TriggerCondition = None
			self.Arg_1: float = None

	def get(self, digitalIo=repcap.DigitalIo.Default) -> DioStruct:
		"""SCPI: TRIGger:CONDition:DIO<IO> \n
		Snippet: value: DioStruct = driver.trigger.condition.dio.get(digitalIo = repcap.DigitalIo.Default) \n
		Sets the trigger condition of the specified Digital I/O line. \n
			:param digitalIo: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Dio')
			:return: structure: for return value, see the help for DioStruct structure arguments."""
		digitalIo_cmd_val = self._cmd_group.get_repcap_cmd_value(digitalIo, repcap.DigitalIo)
		return self._core.io.query_struct(f'TRIGger:CONDition:DIO{digitalIo_cmd_val}?', self.__class__.DioStruct())



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HardCopy:
	"""HardCopy commands group definition. 4 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hardCopy", core, parent)

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPy
			self._formatPy = FormatPy(self._core, self._cmd_group)
		return self._formatPy

	@property
	def size(self):
		"""size commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_size'):
			from .Size import Size
			self._size = Size(self._core, self._cmd_group)
		return self._size

	def get_data(self) -> bytes:
		"""SCPI: HCOPy:DATA \n
		Snippet: value: bytes = driver.hardCopy.get_data() \n
		Returns the actual display content (screenshot) . \n
			:return: result: No help available
		"""
		response = self._core.io.query_bin_block('HCOPy:DATA?')
		return response



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 4 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	@property
	def protection(self):
		"""protection commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_protection'):
			from .Protection import Protection
			self._protection = Protection(self._core, self._cmd_group)
		return self._protection



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Stime:
	"""Stime commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stime", core, parent)

	# noinspection PyTypeChecker
	class SetStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Year: int: No parameter help available
			- Month: int: No parameter help available
			- Day: int: No parameter help available
			- Hour: int: No parameter help available
			- Minute: int: No parameter help available
			- Second: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Year'),
			ArgStruct.scalar_int('Month'),
			ArgStruct.scalar_int('Day'),
			ArgStruct.scalar_int('Hour'),
			ArgStruct.scalar_int('Minute'),
			ArgStruct.scalar_int('Second')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Year: int = None
			self.Month: int = None
			self.Day: int = None
			self.Hour: int = None
			self.Minute: int = None
			self.Second: int = None

	def set(self, structure: SetStruct) -> None:
		"""SCPI: LOG:STIMe \n
		Snippet: driver.log.stime.set(value = [PROPERTY_STRUCT_NAME]()) \n
		Sets or queries the start time of the data logging function. \n
			:param structure: for set value, see the help for SetStruct structure arguments.
		"""
		self._core.io.write_struct(f'LOG:STIMe', structure)

	def get(self) -> str:
		"""SCPI: LOG:STIMe \n
		Snippet: value: str = driver.log.stime.get() \n
		Sets or queries the start time of the data logging function. \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'LOG:STIMe?')
		return trim_str_response(response)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 4 total commands, 2 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._cmd_group)
		return self._data

	@property
	def points(self):
		"""points commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_points'):
			from .Points import Points
			self._points = Points(self._core, self._cmd_group)
		return self._points

	def delete(self, arg_0: str) -> None:
		"""SCPI: DATA:DELete \n
		Snippet: driver.data.delete(arg_0 = '1') \n
		Deletes the specified file from memory. \n
			:param arg_0: Filepath of the file.
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'DATA:DELete {param}')

	def get_list_py(self) -> List[str]:
		"""SCPI: DATA:LIST \n
		Snippet: value: List[str] = driver.data.get_list_py() \n
		Queries all files in internal memory ('/int/') and external memory ('/USB') . \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('DATA:LIST?')
		return Conversions.str_to_str_list(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Immediate:
	"""Immediate commands group definition. 4 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	@property
	def step(self):
		"""step commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_step'):
			from .Step import Step
			self._step = Step(self._core, self._cmd_group)
		return self._step

	@property
	def alimit(self):
		"""alimit commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_alimit'):
			from .Alimit import Alimit
			self._alimit = Alimit(self._core, self._cmd_group)
		return self._alimit

	def get_amplitude(self) -> float:
		"""SCPI: [SOURce]:CURRent[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: value: float = driver.source.current.level.immediate.get_amplitude() \n
		Sets or queries the current value of the selected channel. \n
			:return: current:
				- numeric value: Numeric value in the range of 0.000 to 20.0100 .
				- MIN | MINimum: Minimum current at 0.0005 A.
				- MAX | MAXimum: Depending on the set voltage level, the maximum set current is 20.0100 A.For voltage range up to 32 V, maximum set current is 20.0100 A.For voltage range up to 64 V, maximum set current is 10.0100 A.
				- UP: Increases current by a defined step size. See [SOURce:]CURRent[:LEVel][:IMMediate]:STEP[:INCRement].
				- DOWN: Decreases current by a defined step size. See [SOURce:]CURRent[:LEVel][:IMMediate]:STEP[:INCRement]."""
		response = self._core.io.query_str('SOURce:CURRent:LEVel:IMMediate:AMPLitude?')
		return Conversions.str_to_float(response)

	def set_amplitude(self, current: float) -> None:
		"""SCPI: [SOURce]:CURRent[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: driver.source.current.level.immediate.set_amplitude(current = 1.0) \n
		Sets or queries the current value of the selected channel. \n
			:param current:
				- numeric value: Numeric value in the range of 0.000 to 20.0100 .
				- MIN | MINimum: Minimum current at 0.0005 A.
				- MAX | MAXimum: Depending on the set voltage level, the maximum set current is 20.0100 A.For voltage range up to 32 V, maximum set current is 20.0100 A.For voltage range up to 64 V, maximum set current is 10.0100 A.
				- UP: Increases current by a defined step size. See [SOURce:]CURRent[:LEVel][:IMMediate]:STEP[:INCRement].
				- DOWN: Decreases current by a defined step size. See [SOURce:]CURRent[:LEVel][:IMMediate]:STEP[:INCRement]."""
		param = Conversions.decimal_value_to_str(current)
		self._core.io.write(f'SOURce:CURRent:LEVel:IMMediate:AMPLitude {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Trigger:
	"""Trigger commands group definition. 14 total commands, 7 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trigger", core, parent)

	@property
	def enable(self):
		"""enable commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .Enable import Enable
			self._enable = Enable(self._core, self._cmd_group)
		return self._enable

	@property
	def direction(self):
		"""direction commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_direction'):
			from .Direction import Direction
			self._direction = Direction(self._core, self._cmd_group)
		return self._direction

	@property
	def logic(self):
		"""logic commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_logic'):
			from .Logic import Logic
			self._logic = Logic(self._core, self._cmd_group)
		return self._logic

	@property
	def channel(self):
		"""channel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_channel'):
			from .Channel import Channel
			self._channel = Channel(self._core, self._cmd_group)
		return self._channel

	@property
	def condition(self):
		"""condition commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_condition'):
			from .Condition import Condition
			self._condition = Condition(self._core, self._cmd_group)
		return self._condition

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._cmd_group)
		return self._state

	@property
	def sequence(self):
		"""sequence commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sequence'):
			from .Sequence import Sequence
			self._sequence = Sequence(self._core, self._cmd_group)
		return self._sequence



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, arg_0: enums.LogMode) -> None:
		"""SCPI: LOG:MODE \n
		Snippet: driver.log.mode.set(arg_0 = enums.LogMode.COUNt) \n
		Sets or queries the data logging mode. \n
			:param arg_0:
				- UNLimited: Infinite data capture.
				- COUNt: Number of measurement values to be captured.
				- DURation: Duration of the measurement values capture.
				- SPAN: Interval of the measurement values capture."""
		param = Conversions.enum_scalar_to_str(arg_0, enums.LogMode)
		self._core.io.write(f'LOG:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, arg_0: enums.LogMode) -> enums.LogMode:
		"""SCPI: LOG:MODE \n
		Snippet: value: enums.LogMode = driver.log.mode.get(arg_0 = enums.LogMode.COUNt) \n
		Sets or queries the data logging mode. \n
			:param arg_0:
				- UNLimited: Infinite data capture.
				- COUNt: Number of measurement values to be captured.
				- DURation: Duration of the measurement values capture.
				- SPAN: Interval of the measurement values capture.
			:return: arg_0: No help available"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.LogMode)
		response = self._core.io.query_str(f'LOG:MODE? {param}')
		return Conversions.str_to_scalar_enum(response, enums.LogMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Connection:
	"""Connection commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("connection", core, parent)

	def get_state(self) -> bool:
		"""SCPI: SYSTem:COMMunicate:WLAN:CONNection[:STATe] \n
		Snippet: value: bool = driver.system.communicate.wlan.connection.get_state() \n
		Connects or disconnects WLAN to the predefined wireless access point. Available only if option R&S NGP-K102. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:WLAN:CONNection:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: SYSTem:COMMunicate:WLAN:CONNection[:STATe] \n
		Snippet: driver.system.communicate.wlan.connection.set_state(arg_0 = False) \n
		Connects or disconnects WLAN to the predefined wireless access point. Available only if option R&S NGP-K102. \n
			:param arg_0:
				- 1: Connect WLAN to the predefined wireless access point.
				- 0: Disconnect WLAN from the predefined wireless access point."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:WLAN:CONNection:STATe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Voltage:
	"""Voltage commands group definition. 5 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("voltage", core, parent)

	@property
	def dc(self):
		"""dc commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_dc'):
			from .Dc import Dc
			self._dc = Dc(self._core, self._cmd_group)
		return self._dc



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 13 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("current", core, parent)

	@property
	def protection(self):
		"""protection commands group. 2 Sub-classes, 4 commands."""
		if not hasattr(self, '_protection'):
			from .Protection import Protection
			self._protection = Protection(self._core, self._cmd_group)
		return self._protection

	@property
	def negative(self):
		"""negative commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_negative'):
			from .Negative import Negative
			self._negative = Negative(self._core, self._cmd_group)
		return self._negative

	@property
	def level(self):
		"""level commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_level'):
			from .Level import Level
			self._level = Level(self._core, self._cmd_group)
		return self._level

	def get_range(self) -> float:
		"""SCPI: [SOURce]:CURRent:RANGe \n
		Snippet: value: float = driver.source.current.get_range() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SOURce:CURRent:RANGe?')
		return Conversions.str_to_float(response)

	def set_range(self, arg_0: float) -> None:
		"""SCPI: [SOURce]:CURRent:RANGe \n
		Snippet: driver.source.current.set_range(arg_0 = 1.0) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'SOURce:CURRent:RANGe {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Questionable:
	"""Questionable commands group definition. 10 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("questionable", core, parent)

	@property
	def instrument(self):
		"""instrument commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_instrument'):
			from .Instrument import Instrument
			self._instrument = Instrument(self._core, self._cmd_group)
		return self._instrument



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Simulator:
	"""Simulator commands group definition. 14 total commands, 3 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("simulator", core, parent)

	@property
	def voc(self):
		"""voc commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_voc'):
			from .Voc import Voc
			self._voc = Voc(self._core, self._cmd_group)
		return self._voc

	@property
	def capacity(self):
		"""capacity commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_capacity'):
			from .Capacity import Capacity
			self._capacity = Capacity(self._core, self._cmd_group)
		return self._capacity

	@property
	def current(self):
		"""current commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_current'):
			from .Current import Current
			self._current = Current(self._core, self._cmd_group)
		return self._current

	def get_enable(self) -> bool:
		"""SCPI: BATTery:SIMulator[:ENABle] \n
		Snippet: value: bool = driver.battery.simulator.get_enable() \n
		Sets or queries the battery simulator state. \n
			:return: arg_0: 1 Enables the battery simulator state. 0 Disables the battery simulator state.
		"""
		response = self._core.io.query_str('BATTery:SIMulator:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, arg_0: bool) -> None:
		"""SCPI: BATTery:SIMulator[:ENABle] \n
		Snippet: driver.battery.simulator.set_enable(arg_0 = False) \n
		Sets or queries the battery simulator state. \n
			:param arg_0: 1 Enables the battery simulator state. 0 Disables the battery simulator state.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'BATTery:SIMulator:ENABle {param}')

	def get_soc(self) -> float:
		"""SCPI: BATTery:SIMulator:SOC \n
		Snippet: value: float = driver.battery.simulator.get_soc() \n
		Sets or queries the state of charge (SoC) of the battery simulator. \n
			:return: arg_0: Sets SoC values.
		"""
		response = self._core.io.query_str('BATTery:SIMulator:SOC?')
		return Conversions.str_to_float(response)

	def set_soc(self, arg_0: float) -> None:
		"""SCPI: BATTery:SIMulator:SOC \n
		Snippet: driver.battery.simulator.set_soc(arg_0 = 1.0) \n
		Sets or queries the state of charge (SoC) of the battery simulator. \n
			:param arg_0: Sets SoC values.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'BATTery:SIMulator:SOC {param}')

	def get_resistance(self) -> float:
		"""SCPI: BATTery:SIMulator:RESistance \n
		Snippet: value: float = driver.battery.simulator.get_resistance() \n
		Queries the battery simulator internal resistance (ESR) . \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('BATTery:SIMulator:RESistance?')
		return Conversions.str_to_float(response)

	def get_tvoltage(self) -> float:
		"""SCPI: BATTery:SIMulator:TVOLtage \n
		Snippet: value: float = driver.battery.simulator.get_tvoltage() \n
		Queries the terminal voltage (Vt) . \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('BATTery:SIMulator:TVOLtage?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Immediate:
	"""Immediate commands group definition. 6 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	@property
	def source(self):
		"""source commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import Source
			self._source = Source(self._core, self._cmd_group)
		return self._source



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Voltage:
	"""Voltage commands group definition. 3 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("voltage", core, parent)

	@property
	def umin(self):
		"""umin commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_umin'):
			from .Umin import Umin
			self._umin = Umin(self._core, self._cmd_group)
		return self._umin

	@property
	def umax(self):
		"""umax commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_umax'):
			from .Umax import Umax
			self._umax = Umax(self._core, self._cmd_group)
		return self._umax

	def get_data(self) -> float:
		"""SCPI: CALibration:VOLTage:DATA \n
		Snippet: value: float = driver.calibration.voltage.get_data() \n
		Sets the DMM reading after setting the output voltage level in channel adjustment process. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('CALibration:VOLTage:DATA?')
		return Conversions.str_to_float(response)

	def set_data(self, arg_0: float) -> None:
		"""SCPI: CALibration:VOLTage:DATA \n
		Snippet: driver.calibration.voltage.set_data(arg_0 = 1.0) \n
		Sets the DMM reading after setting the output voltage level in channel adjustment process. \n
			:param arg_0: Measured value from DMM.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'CALibration:VOLTage:DATA {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Window:
	"""Window commands group definition. 2 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("window", core, parent)

	@property
	def text(self):
		"""text commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_text'):
			from .Text import Text
			self._text = Text(self._core, self._cmd_group)
		return self._text



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPy:
	"""FormatPy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, format_py: enums.HcpyFormat) -> None:
		"""SCPI: HCOPy:FORMat \n
		Snippet: driver.hardCopy.formatPy.set(format_py = enums.HcpyFormat.BMP) \n
		No command help available \n
			:param format_py: No help available
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.HcpyFormat)
		self._core.io.write(f'HCOPy:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self, format_py: enums.HcpyFormat) -> enums.HcpyFormat:
		"""SCPI: HCOPy:FORMat \n
		Snippet: value: enums.HcpyFormat = driver.hardCopy.formatPy.get(format_py = enums.HcpyFormat.BMP) \n
		No command help available \n
			:param format_py: No help available
			:return: format_py: No help available"""
		param = Conversions.enum_scalar_to_str(format_py, enums.HcpyFormat)
		response = self._core.io.query_str(f'HCOPy:FORMat? {param}')
		return Conversions.str_to_scalar_enum(response, enums.HcpyFormat)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Link:
	"""Link commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("link", core, parent)

	def set(self, arg_0: List[int]) -> None:
		"""SCPI: FUSE:LINK \n
		Snippet: driver.fuse.link.set(arg_0 = [1, 2, 3]) \n
		Sets or queries the fuses of several selected channels (fuse linking) . \n
			:param arg_0: 0 - Link all other channels to the previously selected channel.
		"""
		param = Conversions.list_to_csv_str(arg_0)
		self._core.io.write(f'FUSE:LINK {param}')

	def get(self, arg_0: List[int]) -> List[int]:
		"""SCPI: FUSE:LINK \n
		Snippet: value: List[int] = driver.fuse.link.get(arg_0 = [1, 2, 3]) \n
		Sets or queries the fuses of several selected channels (fuse linking) . \n
			:param arg_0: 0 - Link all other channels to the previously selected channel.
			:return: arg_0: 0 - Link all other channels to the previously selected channel."""
		param = Conversions.list_to_csv_str(arg_0)
		response = self._core.io.query_bin_or_ascii_int_list(f'FUSE:LINK? {param}')
		return response



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Battery:
	"""Battery commands group definition. 26 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("battery", core, parent)

	@property
	def simulator(self):
		"""simulator commands group. 3 Sub-classes, 4 commands."""
		if not hasattr(self, '_simulator'):
			from .Simulator import Simulator
			self._simulator = Simulator(self._core, self._cmd_group)
		return self._simulator

	@property
	def model(self):
		"""model commands group. 3 Sub-classes, 6 commands."""
		if not hasattr(self, '_model'):
			from .Model import Model
			self._model = Model(self._core, self._cmd_group)
		return self._model

	def get_status(self) -> str:
		"""SCPI: BATTery:STATus \n
		Snippet: value: str = driver.battery.get_status() \n
		Queries the status of the battery (idle, charging or discharging) . \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('BATTery:STATus?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Source:
	"""Source commands group definition. 6 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	@property
	def output(self):
		"""output commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_output'):
			from .Output import Output
			self._output = Output(self._core, self._cmd_group)
		return self._output

	@property
	def omode(self):
		"""omode commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_omode'):
			from .Omode import Omode
			self._omode = Omode(self._core, self._cmd_group)
		return self._omode

	@property
	def dio(self):
		"""dio commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dio'):
			from .Dio import Dio
			self._dio = Dio(self._core, self._cmd_group)
		return self._dio

	def set(self, arg_0: enums.TriggerSource) -> None:
		"""SCPI: TRIGger[:SEQuence][:IMMediate]:SOURce \n
		Snippet: driver.trigger.sequence.immediate.source.set(arg_0 = enums.TriggerSource.DIO) \n
		Sets or queries the trigger source. See Figure 'Overview of trigger IO system'. \n
			:param arg_0: OUTPut | OMODe | DIO OUTPut Trigger source is from the output channel. OMODe Trigger source is from the different modes (CC, CR, CV, Sink, OVP, OCP, OPP and OTP) detected from the output channel. DIO Trigger source is from DIO connector at the instrument rear panel.
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.TriggerSource)
		self._core.io.write(f'TRIGger:SEQuence:IMMediate:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self, arg_0: enums.TriggerSource) -> enums.TriggerSource:
		"""SCPI: TRIGger[:SEQuence][:IMMediate]:SOURce \n
		Snippet: value: enums.TriggerSource = driver.trigger.sequence.immediate.source.get(arg_0 = enums.TriggerSource.DIO) \n
		Sets or queries the trigger source. See Figure 'Overview of trigger IO system'. \n
			:param arg_0: OUTPut | OMODe | DIO OUTPut Trigger source is from the output channel. OMODe Trigger source is from the different modes (CC, CR, CV, Sink, OVP, OCP, OPP and OTP) detected from the output channel. DIO Trigger source is from DIO connector at the instrument rear panel.
			:return: arg_0: OUTPut | OMODe | DIO OUTPut Trigger source is from the output channel. OMODe Trigger source is from the different modes (CC, CR, CV, Sink, OVP, OCP, OPP and OTP) detected from the output channel. DIO Trigger source is from DIO connector at the instrument rear panel."""
		param = Conversions.enum_scalar_to_str(arg_0, enums.TriggerSource)
		response = self._core.io.query_str(f'TRIGger:SEQuence:IMMediate:SOURce? {param}')
		return Conversions.str_to_scalar_enum(response, enums.TriggerSource)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Flog:
	"""Flog commands group definition. 8 total commands, 1 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("flog", core, parent)

	@property
	def file(self):
		"""file commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_file'):
			from .File import File
			self._file = File(self._core, self._cmd_group)
		return self._file

	def get_state(self) -> bool:
		"""SCPI: FLOG[:STATe] \n
		Snippet: value: bool = driver.flog.get_state() \n
		Sets or queries the FastLog state. \n
			:return: arg_0: 1 Enables the FastLog state. 0 Disables the FastLog state.
		"""
		response = self._core.io.query_str('FLOG:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: FLOG[:STATe] \n
		Snippet: driver.flog.set_state(arg_0 = False) \n
		Sets or queries the FastLog state. \n
			:param arg_0: 1 Enables the FastLog state. 0 Disables the FastLog state.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'FLOG:STATe {param}')

	def get_data(self) -> List[float]:
		"""SCPI: FLOG:DATA \n
		Snippet: value: List[float] = driver.flog.get_data() \n
		Queries FastLog data as a block. The block is returned in the binary format starting in the sequence of voltage followed
		by current measurements, i.e. V, I, V, I, .... The R&S NGU accepts the line message EOI and/or the ASCII character NL
		(0Ah) as an indication that data transmission has been completed The binary data stream must be concluded with EOI or NL
		or EOI followed by NL. If the data stream is not concluded with either EOI or NL, the R&S NGU will wait for additional
		data. In the case of a binary data transmission, the R&S NGU ignores the bit combination NL (0Ah) within the data stream.
		The binary data block has the following structure: #<LengthofLength><Length><block_data>
			INTRO_CMD_HELP: Example: #234<block_data> \n
			- <LengthofLength> specifies how many positions the subsequent length specification occupies ('2' in the example)
			- <Length> specifies the number of subsequent bytes ('34' in the example)
			- <binary block data> specifies the binary block data of the specified length
		To configure fastlog for scpi target, see Example 'Configuring fastlog for scpi target'. \n
			:return: result: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list('FLOG:DATA?')
		return response

	def get_triggered(self) -> bool:
		"""SCPI: FLOG:TRIGgered \n
		Snippet: value: bool = driver.flog.get_triggered() \n
		Sets or queries the triggered state of FastLog. See Figure 'Overview of trigger IO system'. \n
			:return: arg_0: 1 Activates the FastLog state. 0 Deactivates the FastLog state.
		"""
		response = self._core.io.query_str('FLOG:TRIGgered?')
		return Conversions.str_to_bool(response)

	def set_triggered(self, arg_0: bool) -> None:
		"""SCPI: FLOG:TRIGgered \n
		Snippet: driver.flog.set_triggered(arg_0 = False) \n
		Sets or queries the triggered state of FastLog. See Figure 'Overview of trigger IO system'. \n
			:param arg_0: 1 Activates the FastLog state. 0 Deactivates the FastLog state.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'FLOG:TRIGgered {param}')

	# noinspection PyTypeChecker
	def get_symbol_rate(self) -> enums.FastLogSampleRate:
		"""SCPI: FLOG:SRATe \n
		Snippet: value: enums.FastLogSampleRate = driver.flog.get_symbol_rate() \n
		Sets or queries the sample rate of the FastLog function. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('FLOG:SRATe?')
		return Conversions.str_to_scalar_enum(response, enums.FastLogSampleRate)

	def set_symbol_rate(self, arg_0: enums.FastLogSampleRate) -> None:
		"""SCPI: FLOG:SRATe \n
		Snippet: driver.flog.set_symbol_rate(arg_0 = enums.FastLogSampleRate.S001k) \n
		Sets or queries the sample rate of the FastLog function. \n
			:param arg_0: 500K | 250K | 125K | 62K5 | 31K25 | 15K625 | 7K812 | 3K906 | 1K953 | 976 | 488 | 244 | 122 | 61 | 30 | 15
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.FastLogSampleRate)
		self._core.io.write(f'FLOG:SRATe {param}')

	def get_stime(self) -> float:
		"""SCPI: FLOG:STIMe \n
		Snippet: value: float = driver.flog.get_stime() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('FLOG:STIMe?')
		return Conversions.str_to_float(response)

	def set_stime(self, arg_0: float) -> None:
		"""SCPI: FLOG:STIMe \n
		Snippet: driver.flog.set_stime(arg_0 = 1.0) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'FLOG:STIMe {param}')

	# noinspection PyTypeChecker
	def get_target(self) -> enums.FastLogTarget:
		"""SCPI: FLOG:TARGet \n
		Snippet: value: enums.FastLogTarget = driver.flog.get_target() \n
		Chose the target the data shall be written to. \n
			:return: arg_0: SCPI | USB SCPI Transfer data to SCPI client. The sum of all sample rates have to be smaller or equal to 500 kS/s. USB Saves data to a binary file which is saved to the direectory specified in the 'Target Folder'.
		"""
		response = self._core.io.query_str('FLOG:TARGet?')
		return Conversions.str_to_scalar_enum(response, enums.FastLogTarget)

	def set_target(self, arg_0: enums.FastLogTarget) -> None:
		"""SCPI: FLOG:TARGet \n
		Snippet: driver.flog.set_target(arg_0 = enums.FastLogTarget.SCPI) \n
		Chose the target the data shall be written to. \n
			:param arg_0: SCPI | USB SCPI Transfer data to SCPI client. The sum of all sample rates have to be smaller or equal to 500 kS/s. USB Saves data to a binary file which is saved to the direectory specified in the 'Target Folder'.
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.FastLogTarget)
		self._core.io.write(f'FLOG:TARGet {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Start:
	"""Start commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	def set(self, arg_0: int) -> None:
		"""SCPI: CALibration:AINPut:STARt \n
		Snippet: driver.calibration.ainput.start.set(arg_0 = 1) \n
		Selects the analog input pin for adjustment. \n
			:param arg_0: Input pin for adjustment.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'CALibration:AINPut:STARt {param}')

	def get(self) -> int:
		"""SCPI: CALibration:AINPut:STARt \n
		Snippet: value: int = driver.calibration.ainput.start.get() \n
		Selects the analog input pin for adjustment. \n
			:return: arg_0: No help available"""
		response = self._core.io.query_str(f'CALibration:AINPut:STARt?')
		return Conversions.str_to_int(response)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fuse:
	"""Fuse commands group definition. 6 total commands, 3 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fuse", core, parent)

	@property
	def link(self):
		"""link commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_link'):
			from .Link import Link
			self._link = Link(self._core, self._cmd_group)
		return self._link

	@property
	def tripped(self):
		"""tripped commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_tripped'):
			from .Tripped import Tripped
			self._tripped = Tripped(self._core, self._cmd_group)
		return self._tripped

	@property
	def delay(self):
		"""delay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_delay'):
			from .Delay import Delay
			self._delay = Delay(self._core, self._cmd_group)
		return self._delay

	def get_state(self) -> bool:
		"""SCPI: FUSE[:STATe] \n
		Snippet: value: bool = driver.fuse.get_state() \n
		Sets or queries the state for over current protection (OCP) . See Example 'Configuring fuses'. \n
			:return: arg_0:
				- 1 | 0:
				- 1: Activates the OCP state.
				- 0: deactivates the OCP state."""
		response = self._core.io.query_str('FUSE:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: FUSE[:STATe] \n
		Snippet: driver.fuse.set_state(arg_0 = False) \n
		Sets or queries the state for over current protection (OCP) . See Example 'Configuring fuses'. \n
			:param arg_0:
				- 1 | 0:
				- 1: Activates the OCP state.
				- 0: deactivates the OCP state."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'FUSE:STATe {param}')

	def set_unlink(self, arg_0: List[int]) -> None:
		"""SCPI: FUSE:UNLink \n
		Snippet: driver.fuse.set_unlink(arg_0 = [1, 2, 3]) \n
		Unlinks fuse linking from the other channels (Ch 1, Ch 2, Ch 3 or Ch 4) . See Example 'Configuring fuses'. \n
			:param arg_0: 0 - Unlink all other channels to the previously selected channel.
		"""
		param = Conversions.list_to_csv_str(arg_0)
		self._core.io.write(f'FUSE:UNLink {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Types import DataType
from ...Internal.Utilities import trim_str_response
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Priority:
	"""Priority commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("priority", core, parent)

	def set(self, arg_0: str) -> None:
		"""SCPI: SOURce:PRIority \n
		Snippet: driver.source.priority.set(arg_0 = r1) \n
		Sets or queries the source priority mode. \n
			:param arg_0: VOLTage | CURRent | list VOLT Set the source measure unit to operate in voltage priority mode. CURR Set the source measure unit to operate in current priority mode.
		"""
		param = Conversions.value_to_str(arg_0)
		self._core.io.write(f'SOURce:PRIority {param}')

	def get(self, arg_0: str, channel_list: str = None) -> str:
		"""SCPI: SOURce:PRIority \n
		Snippet: value: str = driver.source.priority.get(arg_0 = r1, channel_list = r1) \n
		Sets or queries the source priority mode. \n
			:param arg_0: VOLTage | CURRent | list VOLT Set the source measure unit to operate in voltage priority mode. CURR Set the source measure unit to operate in current priority mode.
			:param channel_list: list
			:return: arg_0: VOLTage | CURRent | list VOLT Set the source measure unit to operate in voltage priority mode. CURR Set the source measure unit to operate in current priority mode."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.RawString), ArgSingle('channel_list', channel_list, DataType.RawString, None, is_optional=True))
		response = self._core.io.query_str(f'SOURce:PRIority? {param}'.rstrip())
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dio:
	"""Dio commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: DigitalIo, default value after init: DigitalIo.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dio", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_digitalIo_get', 'repcap_digitalIo_set', repcap.DigitalIo.Nr1)

	def repcap_digitalIo_set(self, digitalIo: repcap.DigitalIo) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to DigitalIo.Default
		Default value after init: DigitalIo.Nr1"""
		self._cmd_group.set_repcap_enum_value(digitalIo)

	def repcap_digitalIo_get(self) -> repcap.DigitalIo:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, arg_0: bool, digitalIo=repcap.DigitalIo.Default) -> None:
		"""SCPI: TRIGger[:ENABle]:DIO<IO> \n
		Snippet: driver.trigger.enable.dio.set(arg_0 = False, digitalIo = repcap.DigitalIo.Default) \n
		Sets or queries the enable state of the specified Digital I/O line. \n
			:param arg_0:
				- 1: Selected Digital /O line is enabled.
				- 0: Selected Digital /O line is disabled.
			:param digitalIo: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Dio')"""
		param = Conversions.bool_to_str(arg_0)
		digitalIo_cmd_val = self._cmd_group.get_repcap_cmd_value(digitalIo, repcap.DigitalIo)
		self._core.io.write(f'TRIGger:ENABle:DIO{digitalIo_cmd_val} {param}')

	def get(self, digitalIo=repcap.DigitalIo.Default) -> bool:
		"""SCPI: TRIGger[:ENABle]:DIO<IO> \n
		Snippet: value: bool = driver.trigger.enable.dio.get(digitalIo = repcap.DigitalIo.Default) \n
		Sets or queries the enable state of the specified Digital I/O line. \n
			:param digitalIo: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Dio')
			:return: arg_0: No help available"""
		digitalIo_cmd_val = self._cmd_group.get_repcap_cmd_value(digitalIo, repcap.DigitalIo)
		response = self._core.io.query_str(f'TRIGger:ENABle:DIO{digitalIo_cmd_val}?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Capacity:
	"""Capacity commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("capacity", core, parent)

	def get_limit(self) -> float:
		"""SCPI: BATTery:SIMulator:CAPacity:LIMit \n
		Snippet: value: float = driver.battery.simulator.capacity.get_limit() \n
		Sets or queries the full battery capacity. \n
			:return: arg_0: Defines the full battery capacity.
		"""
		response = self._core.io.query_str('BATTery:SIMulator:CAPacity:LIMit?')
		return Conversions.str_to_float(response)

	def set_limit(self, arg_0: float) -> None:
		"""SCPI: BATTery:SIMulator:CAPacity:LIMit \n
		Snippet: driver.battery.simulator.capacity.set_limit(arg_0 = 1.0) \n
		Sets or queries the full battery capacity. \n
			:param arg_0: Defines the full battery capacity.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'BATTery:SIMulator:CAPacity:LIMit {param}')

	def get_value(self) -> float:
		"""SCPI: BATTery:SIMulator:CAPacity \n
		Snippet: value: float = driver.battery.simulator.capacity.get_value() \n
		Queries the remaining battery capacity. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('BATTery:SIMulator:CAPacity?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Types import DataType
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Count:
	"""Count commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def set(self, set_new_value: float, return_min_or_max: enums.MinOrMax = None) -> None:
		"""SCPI: LOG:COUNt \n
		Snippet: driver.log.count.set(set_new_value = 1.0, return_min_or_max = enums.MinOrMax.MAX) \n
		Sets or queries the number of measurement values to be captured. \n
			:param set_new_value: No help available
			:param return_min_or_max: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('set_new_value', set_new_value, DataType.Float), ArgSingle('return_min_or_max', return_min_or_max, DataType.Enum, enums.MinOrMax, is_optional=True))
		self._core.io.write(f'LOG:COUNt {param}'.rstrip())

	def get(self, return_min_or_max: enums.MinOrMax = None) -> int:
		"""SCPI: LOG:COUNt \n
		Snippet: value: int = driver.log.count.get(return_min_or_max = enums.MinOrMax.MAX) \n
		Sets or queries the number of measurement values to be captured. \n
			:param return_min_or_max: No help available
			:return: result: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('return_min_or_max', return_min_or_max, DataType.Enum, enums.MinOrMax, is_optional=True))
		response = self._core.io.query_str(f'LOG:COUNt? {param}'.rstrip())
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Immediate:
	"""Immediate commands group definition. 4 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	@property
	def step(self):
		"""step commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_step'):
			from .Step import Step
			self._step = Step(self._core, self._cmd_group)
		return self._step

	@property
	def alimit(self):
		"""alimit commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_alimit'):
			from .Alimit import Alimit
			self._alimit = Alimit(self._core, self._cmd_group)
		return self._alimit

	def get_amplitude(self) -> float:
		"""SCPI: [SOURce]:VOLTage[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: value: float = driver.source.voltage.level.immediate.get_amplitude() \n
		Sets or queries the voltage value of the selected channel. \n
			:return: voltage:
				- numeric value: Numeric value in V.
				- MIN | MINimum: Minimum voltage at 0.000 V.
				- MAX | MAXimum: Maximum voltage at 64.050 V.
				- UP: Increases voltage by a defined step size. See [SOURce:]VOLTage[:LEVel][:IMMediate]:STEP[:INCRement].
				- DOWN: Decreases voltage by a defined step size. See [SOURce:]VOLTage[:LEVel][:IMMediate]:STEP[:INCRement]."""
		response = self._core.io.query_str('SOURce:VOLTage:LEVel:IMMediate:AMPLitude?')
		return Conversions.str_to_float(response)

	def set_amplitude(self, voltage: float) -> None:
		"""SCPI: [SOURce]:VOLTage[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: driver.source.voltage.level.immediate.set_amplitude(voltage = 1.0) \n
		Sets or queries the voltage value of the selected channel. \n
			:param voltage:
				- numeric value: Numeric value in V.
				- MIN | MINimum: Minimum voltage at 0.000 V.
				- MAX | MAXimum: Maximum voltage at 64.050 V.
				- UP: Increases voltage by a defined step size. See [SOURce:]VOLTage[:LEVel][:IMMediate]:STEP[:INCRement].
				- DOWN: Decreases voltage by a defined step size. See [SOURce:]VOLTage[:LEVel][:IMMediate]:STEP[:INCRement]."""
		param = Conversions.decimal_value_to_str(voltage)
		self._core.io.write(f'SOURce:VOLTage:LEVel:IMMediate:AMPLitude {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sense:
	"""Sense commands group definition. 7 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	@property
	def current(self):
		"""current commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_current'):
			from .Current import Current
			self._current = Current(self._core, self._cmd_group)
		return self._current

	@property
	def voltage(self):
		"""voltage commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_voltage'):
			from .Voltage import Voltage
			self._voltage = Voltage(self._core, self._cmd_group)
		return self._voltage

	@property
	def nplCycles(self):
		"""nplCycles commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nplCycles'):
			from .NplCycles import NplCycles
			self._nplCycles = NplCycles(self._core, self._cmd_group)
		return self._nplCycles



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Log:
	"""Log commands group definition. 11 total commands, 7 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("log", core, parent)

	@property
	def channel(self):
		"""channel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_channel'):
			from .Channel import Channel
			self._channel = Channel(self._core, self._cmd_group)
		return self._channel

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import Mode
			self._mode = Mode(self._core, self._cmd_group)
		return self._mode

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import Count
			self._count = Count(self._core, self._cmd_group)
		return self._count

	@property
	def duration(self):
		"""duration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_duration'):
			from .Duration import Duration
			self._duration = Duration(self._core, self._cmd_group)
		return self._duration

	@property
	def interval(self):
		"""interval commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_interval'):
			from .Interval import Interval
			self._interval = Interval(self._core, self._cmd_group)
		return self._interval

	@property
	def fname(self):
		"""fname commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fname'):
			from .Fname import Fname
			self._fname = Fname(self._core, self._cmd_group)
		return self._fname

	@property
	def stime(self):
		"""stime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stime'):
			from .Stime import Stime
			self._stime = Stime(self._core, self._cmd_group)
		return self._stime

	# noinspection PyTypeChecker
	def get_location(self) -> enums.Filename:
		"""SCPI: LOG:LOCation \n
		Snippet: value: enums.Filename = driver.log.get_location() \n
		Sets or queries the logging location. \n
			:return: file_location: No help available
		"""
		response = self._core.io.query_str('LOG:LOCation?')
		return Conversions.str_to_scalar_enum(response, enums.Filename)

	def set_location(self, file_location: enums.Filename) -> None:
		"""SCPI: LOG:LOCation \n
		Snippet: driver.log.set_location(file_location = enums.Filename.DEF) \n
		Sets or queries the logging location. \n
			:param file_location: No help available
		"""
		param = Conversions.enum_scalar_to_str(file_location, enums.Filename)
		self._core.io.write(f'LOG:LOCation {param}')

	def get_data(self) -> List[float]:
		"""SCPI: LOG:DATA \n
		Snippet: value: List[float] = driver.log.get_data() \n
		Returns 12 sets of latest logging data with minimum logging interval (8 ms) . Depending on the models, the data is
		returned in the following format for a 2-channel models: <Ch1_voltage>, <Ch1_current>,<Ch1_power>,<Ch2_voltage>,
		<Ch2_current>,<Ch2_power>, <Ch1_voltage>, <Ch1_current>,<Ch1_power>, <Ch2_voltage>, <Ch2_current>,<Ch2_power>... \n
			:return: result: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list('LOG:DATA?')
		return response

	def get_triggered(self) -> int or bool:
		"""SCPI: LOG:TRIGgered \n
		Snippet: value: int or bool = driver.log.get_triggered() \n
		Sets or queries the state for manual trigger logging function. \n
			:return: arg_0: (integer or boolean) No help available
		"""
		response = self._core.io.query_str('LOG:TRIGgered?')
		return Conversions.str_to_int_or_bool(response)

	def set_triggered(self, arg_0: int or bool) -> None:
		"""SCPI: LOG:TRIGgered \n
		Snippet: driver.log.set_triggered(arg_0 = 1) \n
		Sets or queries the state for manual trigger logging function. \n
			:param arg_0: (integer or boolean) 0 Manual trigger function is disabled. 1 Manual trigger function is enabled.
		"""
		param = Conversions.decimal_or_bool_value_to_str(arg_0)
		self._core.io.write(f'LOG:TRIGgered {param}')

	def get_state(self) -> bool:
		"""SCPI: LOG[:STATe] \n
		Snippet: value: bool = driver.log.get_state() \n
		Sets or queries the data logging state. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('LOG:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: LOG[:STATe] \n
		Snippet: driver.log.set_state(arg_0 = False) \n
		Sets or queries the data logging state. \n
			:param arg_0:
				- 1: Data logging function is enabled.
				- 0: Data logging function is disabled."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'LOG:STATe {param}')



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, arg_0: List[int], arg_1: List[float], arg_2: List[float]) -> None:
		"""SCPI: BATTery:MODel:DATA \n
		Snippet: driver.battery.model.data.set(arg_0 = [1, 2, 3], arg_1 = [1.1, 2.2, 3.3], arg_2 = [1.1, 2.2, 3.3]) \n
		Sets or queries the battery model data. \n
			:param arg_0: Sets the value for battery state of charge (SoC) .
			:param arg_1: Sets the value for battery open-circuit voltage (Voc) .
			:param arg_2: Sets the value for battery internal resistance (ESR) .
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('arg_0', arg_0, DataType.IntegerList, None), ArgSingle.as_open_list('arg_1', arg_1, DataType.FloatList, None), ArgSingle.as_open_list('arg_2', arg_2, DataType.FloatList, None))
		self._core.io.write(f'BATTery:MODel:DATA {param}'.rstrip())

	# noinspection PyTypeChecker
	class DataStruct(StructBase):
		"""Response structure. Fields: \n
			- Arg_0: List[int]: Sets the value for battery state of charge (SoC) .
			- Arg_1: List[float]: Sets the value for battery open-circuit voltage (Voc) .
			- Arg_2: List[float]: Sets the value for battery internal resistance (ESR) ."""
		__meta_args_list = [
			ArgStruct('Arg_0', DataType.IntegerList, None, False, True, 1),
			ArgStruct('Arg_1', DataType.FloatList, None, False, True, 1),
			ArgStruct('Arg_2', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Arg_0: List[int] = None
			self.Arg_1: List[float] = None
			self.Arg_2: List[float] = None

	def get(self) -> DataStruct:
		"""SCPI: BATTery:MODel:DATA \n
		Snippet: value: DataStruct = driver.battery.model.data.get() \n
		Sets or queries the battery model data. \n
			:return: structure: for return value, see the help for DataStruct structure arguments."""
		return self._core.io.query_struct(f'BATTery:MODel:DATA?', self.__class__.DataStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Immediate:
	"""Immediate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def get_amplitude(self) -> float:
		"""SCPI: SOURce:VOLTage:NEGative[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: value: float = driver.source.voltage.negative.level.immediate.get_amplitude() \n
		Sets or queries the negative voltage value. Applicable only with NGU401 model. \n
			:return: voltage: numeric value | MIN | MINimum | MAX | MAXimum | UP | DOWN | list numeric value Numeric value in V. MIN | MINimum Minimum voltage at 0.000 V. MAX | MAXimum Maximum voltage at 64.050 V. UP Increases voltage by a defined step size. See [SOURce:]VOLTage[:LEVel][:IMMediate]:STEP[:INCRement]. DOWN Decreases voltage by a defined step size. See [SOURce:]VOLTage[:LEVel][:IMMediate]:STEP[:INCRement]. Range: 0.000 to 64.050
		"""
		response = self._core.io.query_str('SOURce:VOLTage:NEGative:LEVel:IMMediate:AMPLitude?')
		return Conversions.str_to_float(response)

	def set_amplitude(self, voltage: float) -> None:
		"""SCPI: SOURce:VOLTage:NEGative[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: driver.source.voltage.negative.level.immediate.set_amplitude(voltage = 1.0) \n
		Sets or queries the negative voltage value. Applicable only with NGU401 model. \n
			:param voltage: numeric value | MIN | MINimum | MAX | MAXimum | UP | DOWN | list numeric value Numeric value in V. MIN | MINimum Minimum voltage at 0.000 V. MAX | MAXimum Maximum voltage at 64.050 V. UP Increases voltage by a defined step size. See [SOURce:]VOLTage[:LEVel][:IMMediate]:STEP[:INCRement]. DOWN Decreases voltage by a defined step size. See [SOURce:]VOLTage[:LEVel][:IMMediate]:STEP[:INCRement]. Range: 0.000 to 64.050
		"""
		param = Conversions.decimal_value_to_str(voltage)
		self._core.io.write(f'SOURce:VOLTage:NEGative:LEVel:IMMediate:AMPLitude {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Triggered:
	"""Triggered commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("triggered", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._cmd_group)
		return self._state

	@property
	def behavior(self):
		"""behavior commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_behavior'):
			from .Behavior import Behavior
			self._behavior = Behavior(self._core, self._cmd_group)
		return self._behavior



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 3 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("enable", core, parent)

	@property
	def dio(self):
		"""dio commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dio'):
			from .Dio import Dio
			self._dio = Dio(self._core, self._cmd_group)
		return self._dio

	@property
	def select(self):
		"""select commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_select'):
			from .Select import Select
			self._select = Select(self._core, self._cmd_group)
		return self._select

	def get_general(self) -> bool:
		"""SCPI: TRIGger[:ENABle]:GENeral \n
		Snippet: value: bool = driver.trigger.enable.get_general() \n
		Sets or queries the enable state of the master on/off of Digital I/O trigger. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('TRIGger:ENABle:GENeral?')
		return Conversions.str_to_bool(response)

	def set_general(self, arg_0: bool) -> None:
		"""SCPI: TRIGger[:ENABle]:GENeral \n
		Snippet: driver.trigger.enable.set_general(arg_0 = False) \n
		Sets or queries the enable state of the master on/off of Digital I/O trigger. \n
			:param arg_0:
				- 1: Master state of Digital I/O trigger is enabled.
				- 0: Master state of Digital I/O trigger is disabled."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'TRIGger:ENABle:GENeral {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Limit:
	"""Limit commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("limit", core, parent)

	def get_eod(self) -> float:
		"""SCPI: BATTery:SIMulator:CURRent:LIMit:EOD \n
		Snippet: value: float = driver.battery.simulator.current.limit.get_eod() \n
		Sets or queries the current limit at end-of-discharge. \n
			:return: arg_0: Sets the current limit at end-of-discharge.
		"""
		response = self._core.io.query_str('BATTery:SIMulator:CURRent:LIMit:EOD?')
		return Conversions.str_to_float(response)

	def set_eod(self, arg_0: float) -> None:
		"""SCPI: BATTery:SIMulator:CURRent:LIMit:EOD \n
		Snippet: driver.battery.simulator.current.limit.set_eod(arg_0 = 1.0) \n
		Sets or queries the current limit at end-of-discharge. \n
			:param arg_0: Sets the current limit at end-of-discharge.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'BATTery:SIMulator:CURRent:LIMit:EOD {param}')

	def get_regular(self) -> float:
		"""SCPI: BATTery:SIMulator:CURRent:LIMit:REGular \n
		Snippet: value: float = driver.battery.simulator.current.limit.get_regular() \n
		Sets or queries the current limit at regular charge level. \n
			:return: arg_0: Sets the current limit at regular charge level.
		"""
		response = self._core.io.query_str('BATTery:SIMulator:CURRent:LIMit:REGular?')
		return Conversions.str_to_float(response)

	def set_regular(self, arg_0: float) -> None:
		"""SCPI: BATTery:SIMulator:CURRent:LIMit:REGular \n
		Snippet: driver.battery.simulator.current.limit.set_regular(arg_0 = 1.0) \n
		Sets or queries the current limit at regular charge level. \n
			:param arg_0: Sets the current limit at regular charge level.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'BATTery:SIMulator:CURRent:LIMit:REGular {param}')

	def get_eoc(self) -> float:
		"""SCPI: BATTery:SIMulator:CURRent:LIMit:EOC \n
		Snippet: value: float = driver.battery.simulator.current.limit.get_eoc() \n
		Sets or queries the current limit at end-of-charge. \n
			:return: arg_0: Sets the current limit at end-of-charge.
		"""
		response = self._core.io.query_str('BATTery:SIMulator:CURRent:LIMit:EOC?')
		return Conversions.str_to_float(response)

	def set_eoc(self, arg_0: float) -> None:
		"""SCPI: BATTery:SIMulator:CURRent:LIMit:EOC \n
		Snippet: driver.battery.simulator.current.limit.set_eoc(arg_0 = 1.0) \n
		Sets or queries the current limit at end-of-charge. \n
			:param arg_0: Sets the current limit at end-of-charge.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'BATTery:SIMulator:CURRent:LIMit:EOC {param}')

	def get_value(self) -> float:
		"""SCPI: BATTery:SIMulator:CURRent:LIMit \n
		Snippet: value: float = driver.battery.simulator.current.limit.get_value() \n
		Sets or queries the current limit from specific channel. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('BATTery:SIMulator:CURRent:LIMit?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ntransition:
	"""Ntransition commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ntransition", core, parent)

	def set(self, arg_0: int, channel=repcap.Channel.Default) -> None:
		"""SCPI: STATus:OPERation:INSTrument:ISUMmary<Channel>:NTRansition \n
		Snippet: driver.status.operation.instrument.isummary.ntransition.set(arg_0 = 1, channel = repcap.Channel.Default) \n
		Sets or queries the negative transition filter. Setting a bit in the negative transition filter shall cause a 1 to 0
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:param arg_0: No help available
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'STATus:OPERation:INSTrument:ISUMmary{channel_cmd_val}:NTRansition {param}')

	def get(self, channel=repcap.Channel.Default) -> int:
		"""SCPI: STATus:OPERation:INSTrument:ISUMmary<Channel>:NTRansition \n
		Snippet: value: int = driver.status.operation.instrument.isummary.ntransition.get(channel = repcap.Channel.Default) \n
		Sets or queries the negative transition filter. Setting a bit in the negative transition filter shall cause a 1 to 0
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
			:return: arg_0: No help available"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'STATus:OPERation:INSTrument:ISUMmary{channel_cmd_val}:NTRansition?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Link:
	"""Link commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("link", core, parent)

	def set(self, arg_0: int) -> None:
		"""SCPI: [SOURce]:CURRent:PROTection:LINK \n
		Snippet: driver.source.current.protection.link.set(arg_0 = 1) \n
		Sets or queries the fuses of several selected channels (fuse linking) . \n
			:param arg_0: 1 | 2
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'SOURce:CURRent:PROTection:LINK {param}')

	def get(self, arg_0: int) -> int:
		"""SCPI: [SOURce]:CURRent:PROTection:LINK \n
		Snippet: value: int = driver.source.current.protection.link.get(arg_0 = 1) \n
		Sets or queries the fuses of several selected channels (fuse linking) . \n
			:param arg_0: 1 | 2
			:return: arg_0: 1 | 2"""
		param = Conversions.decimal_value_to_str(arg_0)
		response = self._core.io.query_str(f'SOURce:CURRent:PROTection:LINK? {param}')
		return Conversions.str_to_int(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Usb:
	"""Usb commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("usb", core, parent)

	# noinspection PyTypeChecker
	def get_class_py(self) -> enums.UsbClass:
		"""SCPI: INTerfaces:USB:CLASs \n
		Snippet: value: enums.UsbClass = driver.interfaces.usb.get_class_py() \n
		Sets or queries the USB class. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('INTerfaces:USB:CLASs?')
		return Conversions.str_to_scalar_enum(response, enums.UsbClass)

	def set_class_py(self, arg_0: enums.UsbClass) -> None:
		"""SCPI: INTerfaces:USB:CLASs \n
		Snippet: driver.interfaces.usb.set_class_py(arg_0 = enums.UsbClass.CDC) \n
		Sets or queries the USB class. \n
			:param arg_0:
				- CDC: USB CDC connection.
				- TMC: USB TMC connection."""
		param = Conversions.enum_scalar_to_str(arg_0, enums.UsbClass)
		self._core.io.write(f'INTerfaces:USB:CLASs {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Signal:
	"""Signal commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("signal", core, parent)

	def set(self, arg_0: int, arg_1: enums.DioSignal) -> None:
		"""SCPI: DIO:OUTPut:SIGNal \n
		Snippet: driver.dio.output.signal.set(arg_0 = 1, arg_1 = enums.DioSignal.CONStant) \n
		Select digital output signal type. \n
			:param arg_0: Channel number.
			:param arg_1: CONStant | PULSe CONStant An constant level trigger signal is sent out PULSe An output pulse of 100 ms trigger signal is sent out
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.Integer), ArgSingle('arg_1', arg_1, DataType.Enum, enums.DioSignal))
		self._core.io.write_with_opc(f'DIO:OUTPut:SIGNal {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self, arg_0: int) -> enums.DioSignal:
		"""SCPI: DIO:OUTPut:SIGNal \n
		Snippet: value: enums.DioSignal = driver.dio.output.signal.get(arg_0 = 1) \n
		Select digital output signal type. \n
			:param arg_0: Channel number.
			:return: arg_1: CONStant | PULSe CONStant An constant level trigger signal is sent out PULSe An output pulse of 100 ms trigger signal is sent out"""
		param = Conversions.decimal_value_to_str(arg_0)
		response = self._core.io.query_str_with_opc(f'DIO:OUTPut:SIGNal? {param}')
		return Conversions.str_to_scalar_enum(response, enums.DioSignal)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Output:
	"""Output commands group definition. 3 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._cmd_group)
		return self._state

	@property
	def source(self):
		"""source commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import Source
			self._source = Source(self._core, self._cmd_group)
		return self._source

	@property
	def signal(self):
		"""signal commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_signal'):
			from .Signal import Signal
			self._signal = Signal(self._core, self._cmd_group)
		return self._signal



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Text:
	"""Text commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("text", core, parent)

	def set_data(self, custom_message: str) -> None:
		"""SCPI: DISPlay[:WINDow]:TEXT[:DATA] \n
		Snippet: driver.display.window.text.set_data(custom_message = r1) \n
		Shows the text message box on the front display. \n
			:param custom_message: New value for text message box.
		"""
		param = Conversions.value_to_str(custom_message)
		self._core.io.write(f'DISPlay:WINDow:TEXT:DATA {param}')

	def clear(self) -> None:
		"""SCPI: DISPlay[:WINDow]:TEXT:CLEar \n
		Snippet: driver.display.window.text.clear() \n
		Clears the text message box on the front display. \n
		"""
		self._core.io.write(f'DISPlay:WINDow:TEXT:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: DISPlay[:WINDow]:TEXT:CLEar \n
		Snippet: driver.display.window.text.clear_with_opc() \n
		Clears the text message box on the front display. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DISPlay:WINDow:TEXT:CLEar', opc_timeout_ms)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Interfaces:
	"""Interfaces commands group definition. 1 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("interfaces", core, parent)

	@property
	def usb(self):
		"""usb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_usb'):
			from .Usb import Usb
			self._usb = Usb(self._core, self._cmd_group)
		return self._usb



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Impedance:
	"""Impedance commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("impedance", core, parent)

	def get_state(self) -> bool:
		"""SCPI: OUTPut:IMPedance[:STATe] \n
		Snippet: value: bool = driver.output.impedance.get_state() \n
		Sets or queries the output impedance state for the selected channel. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str_with_opc('OUTPut:IMPedance:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: OUTPut:IMPedance[:STATe] \n
		Snippet: driver.output.impedance.set_state(arg_0 = False) \n
		Sets or queries the output impedance state for the selected channel. \n
			:param arg_0:
				- 0: Deactivates output impedance for the selected channel.
				- 1: Activates output impedance for the selected channel."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:IMPedance:STATe {param}')

	def get_value(self) -> float:
		"""SCPI: OUTPut:IMPedance \n
		Snippet: value: float = driver.output.impedance.get_value() \n
		Sets or queries source impedance for the signal specified in ohms. \n
			:return: arg_0: numeric value | MIN | MINimum | MAX | MAXimum | DEF | DEFault | list numeric value Numeric value of the impedance ohm. MIN | MINimum Minimum value of the impedance at -0.05 ohms. MAX | MAXimum Maximum value of the impedance at 100 ohms. DEF Default value of the impedance at 0 ohms. Unit: ohm
		"""
		response = self._core.io.query_str_with_opc('OUTPut:IMPedance?')
		return Conversions.str_to_float(response)

	def set_value(self, arg_0: float) -> None:
		"""SCPI: OUTPut:IMPedance \n
		Snippet: driver.output.impedance.set_value(arg_0 = 1.0) \n
		Sets or queries source impedance for the signal specified in ohms. \n
			:param arg_0: numeric value | MIN | MINimum | MAX | MAXimum | DEF | DEFault | list numeric value Numeric value of the impedance ohm. MIN | MINimum Minimum value of the impedance at -0.05 ohms. MAX | MAXimum Maximum value of the impedance at 100 ohms. DEF Default value of the impedance at 0 ohms. Unit: ohm
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:IMPedance {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Types import DataType
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NplCycles:
	"""NplCycles commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nplCycles", core, parent)

	def set(self, arg_0: float, arg_1: str = None) -> None:
		"""SCPI: [SENSe]:NPLCycles \n
		Snippet: driver.sense.nplCycles.set(arg_0 = 1.0, arg_1 = r1) \n
		Sets or queries the number of power line cycles for measurements. \n
			:param arg_0: Number of power line cycles for measurements.
			:param arg_1: list
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.Float), ArgSingle('arg_1', arg_1, DataType.RawString, None, is_optional=True))
		self._core.io.write(f'SENSe:NPLCycles {param}'.rstrip())

	def get(self, arg_1: str = None) -> float:
		"""SCPI: [SENSe]:NPLCycles \n
		Snippet: value: float = driver.sense.nplCycles.get(arg_1 = r1) \n
		Sets or queries the number of power line cycles for measurements. \n
			:param arg_1: list
			:return: arg_0: Number of power line cycles for measurements."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_1', arg_1, DataType.RawString, None, is_optional=True))
		response = self._core.io.query_str(f'SENSe:NPLCycles? {param}'.rstrip())
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Protection:
	"""Protection commands group definition. 7 total commands, 2 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("protection", core, parent)

	@property
	def link(self):
		"""link commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_link'):
			from .Link import Link
			self._link = Link(self._core, self._cmd_group)
		return self._link

	@property
	def delay(self):
		"""delay commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_delay'):
			from .Delay import Delay
			self._delay = Delay(self._core, self._cmd_group)
		return self._delay

	def get_state(self) -> bool:
		"""SCPI: [SOURce]:CURRent:PROTection[:STATe] \n
		Snippet: value: bool = driver.source.current.protection.get_state() \n
		Sets or queries the OCP state. \n
			:return: arg_0: 1 Activates the OCP state. 0 deactivates the OCP state.
		"""
		response = self._core.io.query_str('SOURce:CURRent:PROTection:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: [SOURce]:CURRent:PROTection[:STATe] \n
		Snippet: driver.source.current.protection.set_state(arg_0 = False) \n
		Sets or queries the OCP state. \n
			:param arg_0: 1 Activates the OCP state. 0 deactivates the OCP state.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SOURce:CURRent:PROTection:STATe {param}')

	def set_unlink(self, arg_0: int) -> None:
		"""SCPI: [SOURce]:CURRent:PROTection:UNLink \n
		Snippet: driver.source.current.protection.set_unlink(arg_0 = 1) \n
		Unlink fuse linking from the other channel (Ch1 or Ch2) . See Example 'Configuring fuses'. \n
			:param arg_0: 1 | 2
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'SOURce:CURRent:PROTection:UNLink {param}')

	def get_tripped(self) -> bool:
		"""SCPI: [SOURce]:CURRent:PROTection:TRIPped \n
		Snippet: value: bool = driver.source.current.protection.get_tripped() \n
		Queries the OCP state of the selected channel. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('SOURce:CURRent:PROTection:TRIPped?')
		return Conversions.str_to_bool(response)

	def clear(self) -> None:
		"""SCPI: [SOURce]:CURRent:PROTection:CLEar \n
		Snippet: driver.source.current.protection.clear() \n
		Resets the OCP state of the selected channel. If an OCP event has occurred before, the reset also erases the message on
		the display. \n
		"""
		self._core.io.write(f'SOURce:CURRent:PROTection:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce]:CURRent:PROTection:CLEar \n
		Snippet: driver.source.current.protection.clear_with_opc() \n
		Resets the OCP state of the selected channel. If an OCP event has occurred before, the reset also erases the message on
		the display. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce:CURRent:PROTection:CLEar', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Negative:
	"""Negative commands group definition. 1 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("negative", core, parent)

	@property
	def level(self):
		"""level commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_level'):
			from .Level import Level
			self._level = Level(self._core, self._cmd_group)
		return self._level



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Select:
	"""Select commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, channel: int) -> None:
		"""SCPI: INSTrument:NSELect \n
		Snippet: driver.instrument.select.set(channel = 1) \n
		Selects or queries the channel by number. \n
			:param channel: No help available
		"""
		param = Conversions.decimal_value_to_str(channel)
		self._core.io.write(f'INSTrument:NSELect {param}')

	def get(self) -> int:
		"""SCPI: INSTrument:NSELect \n
		Snippet: value: int = driver.instrument.select.get() \n
		Selects or queries the channel by number. \n
			:return: channel: No help available"""
		response = self._core.io.query_str(f'INSTrument:NSELect?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Energy:
	"""Energy commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("energy", core, parent)

	def get_state(self) -> bool:
		"""SCPI: MEASure[:SCALar]:ENERgy:STATe \n
		Snippet: value: bool = driver.measure.scalar.energy.get_state() \n
		Sets or queries the energy counter state for the selected channel. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:ENERgy:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: MEASure[:SCALar]:ENERgy:STATe \n
		Snippet: driver.measure.scalar.energy.set_state(arg_0 = False) \n
		Sets or queries the energy counter state for the selected channel. \n
			:param arg_0:
				- 1: Activates the energy counter.
				- 0: Deactivates the energy counter."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'MEASure:SCALar:ENERgy:STATe {param}')

	def reset(self) -> None:
		"""SCPI: MEASure[:SCALar]:ENERgy:RESet \n
		Snippet: driver.measure.scalar.energy.reset() \n
		Resets the energy counter for the selected channel. \n
		"""
		self._core.io.write(f'MEASure:SCALar:ENERgy:RESet')

	def reset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: MEASure[:SCALar]:ENERgy:RESet \n
		Snippet: driver.measure.scalar.energy.reset_with_opc() \n
		Resets the energy counter for the selected channel. \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'MEASure:SCALar:ENERgy:RESet', opc_timeout_ms)

	def get_value(self) -> float:
		"""SCPI: MEASure[:SCALar]:ENERgy \n
		Snippet: value: float = driver.measure.scalar.energy.get_value() \n
		Queries the measured the current released energy value of the previous selected channel. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:ENERgy?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Instrument:
	"""Instrument commands group definition. 10 total commands, 1 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("instrument", core, parent)

	@property
	def isummary(self):
		"""isummary commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_isummary'):
			from .Isummary import Isummary
			self._isummary = Isummary(self._core, self._cmd_group)
		return self._isummary

	def get_event(self) -> int:
		"""SCPI: STATus:QUEStionable:INSTrument[:EVENt] \n
		Snippet: value: int = driver.status.questionable.instrument.get_event() \n
		Returns the contents of the EVENt part of the status register to check whether an event has occurred since the last
		reading. Reading an EVENt register deletes its contents. \n
			:return: result: Event bits in decimal representation
		"""
		response = self._core.io.query_str('STATus:QUEStionable:INSTrument:EVENt?')
		return Conversions.str_to_int(response)

	def get_condition(self) -> int:
		"""SCPI: STATus:QUEStionable:INSTrument:CONDition \n
		Snippet: value: int = driver.status.questionable.instrument.get_condition() \n
		Returns the contents of the CONDition part of the status register to check for questionable instrument or measurement
		states. Reading the CONDition registers does not delete the contents. \n
			:return: result: Condition bits in decimal representation
		"""
		response = self._core.io.query_str('STATus:QUEStionable:INSTrument:CONDition?')
		return Conversions.str_to_int(response)

	def get_ptransition(self) -> int:
		"""SCPI: STATus:QUEStionable:INSTrument:PTRansition \n
		Snippet: value: int = driver.status.questionable.instrument.get_ptransition() \n
		Sets or queries the positive transition filter. Setting a bit in the positive transition filter shall cause a 0 to 1
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('STATus:QUEStionable:INSTrument:PTRansition?')
		return Conversions.str_to_int(response)

	def set_ptransition(self, arg_0: int) -> None:
		"""SCPI: STATus:QUEStionable:INSTrument:PTRansition \n
		Snippet: driver.status.questionable.instrument.set_ptransition(arg_0 = 1) \n
		Sets or queries the positive transition filter. Setting a bit in the positive transition filter shall cause a 0 to 1
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'STATus:QUEStionable:INSTrument:PTRansition {param}')

	def get_ntransition(self) -> int:
		"""SCPI: STATus:QUEStionable:INSTrument:NTRansition \n
		Snippet: value: int = driver.status.questionable.instrument.get_ntransition() \n
		Sets or queries the negative transition filter. Setting a bit in the negative transition filter shall cause a 1 to 0
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('STATus:QUEStionable:INSTrument:NTRansition?')
		return Conversions.str_to_int(response)

	def set_ntransition(self, arg_0: int) -> None:
		"""SCPI: STATus:QUEStionable:INSTrument:NTRansition \n
		Snippet: driver.status.questionable.instrument.set_ntransition(arg_0 = 1) \n
		Sets or queries the negative transition filter. Setting a bit in the negative transition filter shall cause a 1 to 0
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'STATus:QUEStionable:INSTrument:NTRansition {param}')

	def get_enable(self) -> int:
		"""SCPI: STATus:QUEStionable:INSTrument:ENABle \n
		Snippet: value: int = driver.status.questionable.instrument.get_enable() \n
		Sets or queries the enable mask that allows true conditions in the EVENt part to be reported in the summary bit. If a bit
		in the ENABle part is 1, and the corresponding EVENt bit is true, a positive transition occurs in the summary bit. This
		transition is reported to the next higher level. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('STATus:QUEStionable:INSTrument:ENABle?')
		return Conversions.str_to_int(response)

	def set_enable(self, arg_0: int) -> None:
		"""SCPI: STATus:QUEStionable:INSTrument:ENABle \n
		Snippet: driver.status.questionable.instrument.set_enable(arg_0 = 1) \n
		Sets or queries the enable mask that allows true conditions in the EVENt part to be reported in the summary bit. If a bit
		in the ENABle part is 1, and the corresponding EVENt bit is true, a positive transition occurs in the summary bit. This
		transition is reported to the next higher level. \n
			:param arg_0: Bit mask in decimal representation
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'STATus:QUEStionable:INSTrument:ENABle {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Immediate:
	"""Immediate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def get_amplitude(self) -> float:
		"""SCPI: SOURce:CURRent:NEGative[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: value: float = driver.source.current.negative.level.immediate.get_amplitude() \n
		Sets or queries the negative current value. \n
			:return: current: numeric value | MIN | MINimum | MAX | MAXimum | UP | DOWN | list numeric value Numeric value in the range of 0.000 to 20.0100 . MIN | MINimum Minimum current at 0.0005 A. MAX | MAXimum Depending on the set voltage level, the maximum set current is 20.0100 A. For voltage range up to 32 V, maximum set current is 20.0100 A. For voltage range up to 64 V, maximum set current is 10.0100 A. UP Increases current by a defined step size. See [SOURce:]CURRent[:LEVel][:IMMediate]:STEP[:INCRement]. DOWN Decreases current by a defined step size. See [SOURce:]CURRent[:LEVel][:IMMediate]:STEP[:INCRement].
		"""
		response = self._core.io.query_str('SOURce:CURRent:NEGative:LEVel:IMMediate:AMPLitude?')
		return Conversions.str_to_float(response)

	def set_amplitude(self, current: float) -> None:
		"""SCPI: SOURce:CURRent:NEGative[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: driver.source.current.negative.level.immediate.set_amplitude(current = 1.0) \n
		Sets or queries the negative current value. \n
			:param current: numeric value | MIN | MINimum | MAX | MAXimum | UP | DOWN | list numeric value Numeric value in the range of 0.000 to 20.0100 . MIN | MINimum Minimum current at 0.0005 A. MAX | MAXimum Depending on the set voltage level, the maximum set current is 20.0100 A. For voltage range up to 32 V, maximum set current is 20.0100 A. For voltage range up to 64 V, maximum set current is 10.0100 A. UP Increases current by a defined step size. See [SOURce:]CURRent[:LEVel][:IMMediate]:STEP[:INCRement]. DOWN Decreases current by a defined step size. See [SOURce:]CURRent[:LEVel][:IMMediate]:STEP[:INCRement].
		"""
		param = Conversions.decimal_value_to_str(current)
		self._core.io.write(f'SOURce:CURRent:NEGative:LEVel:IMMediate:AMPLitude {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 5 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("current", core, parent)

	@property
	def limit(self):
		"""limit commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_limit'):
			from .Limit import Limit
			self._limit = Limit(self._core, self._cmd_group)
		return self._limit

	def get_value(self) -> float:
		"""SCPI: BATTery:SIMulator:CURRent \n
		Snippet: value: float = driver.battery.simulator.current.get_value() \n
		Queries the current (A) of battery simulator. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('BATTery:SIMulator:CURRent?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Display:
	"""Display commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("display", core, parent)

	@property
	def window(self):
		"""window commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_window'):
			from .Window import Window
			self._window = Window(self._core, self._cmd_group)
		return self._window

	def get_brightness(self) -> float:
		"""SCPI: DISPlay:BRIGhtness \n
		Snippet: value: float = driver.display.get_brightness() \n
		Sets or queries the display brightness. \n
			:return: display_brightness: No help available
		"""
		response = self._core.io.query_str('DISPlay:BRIGhtness?')
		return Conversions.str_to_float(response)

	def set_brightness(self, display_brightness: float) -> None:
		"""SCPI: DISPlay:BRIGhtness \n
		Snippet: driver.display.set_brightness(display_brightness = 1.0) \n
		Sets or queries the display brightness. \n
			:param display_brightness: Displays brightness for the instrument.
		"""
		param = Conversions.decimal_value_to_str(display_brightness)
		self._core.io.write(f'DISPlay:BRIGhtness {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Lower:
	"""Lower commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lower", core, parent)

	def set(self, voltage: float) -> None:
		"""SCPI: [SOURce]:VOLTage[:LEVel][:IMMediate]:ALIMit:LOWer \n
		Snippet: driver.source.voltage.level.immediate.alimit.lower.set(voltage = 1.0) \n
		Sets or queries the lower safety limit for voltage. \n
			:param voltage:
				- numeric value: Numeric value for safety limit.
				- MIN | MINimum: Min value for lower safety limit.
				- MAX | MAXimum: Max value for lower safety limit."""
		param = Conversions.decimal_value_to_str(voltage)
		self._core.io.write(f'SOURce:VOLTage:LEVel:IMMediate:ALIMit:LOWer {param}')

	def get(self) -> float:
		"""SCPI: [SOURce]:VOLTage[:LEVel][:IMMediate]:ALIMit:LOWer \n
		Snippet: value: float = driver.source.voltage.level.immediate.alimit.lower.get() \n
		Sets or queries the lower safety limit for voltage. \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'SOURce:VOLTage:LEVel:IMMediate:ALIMit:LOWer?')
		return Conversions.str_to_float(response)



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Block:
	"""Block commands group definition. 6 total commands, 1 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("block", core, parent)

	@property
	def fname(self):
		"""fname commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fname'):
			from .Fname import Fname
			self._fname = Fname(self._core, self._cmd_group)
		return self._fname

	def get_data(self) -> List[float]:
		"""SCPI: ARBitrary:BLOCk:DATA \n
		Snippet: value: List[float] = driver.arbitrary.block.get_data() \n
		Define the data points for a whole block. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list('ARBitrary:BLOCk:DATA?')
		return response

	def set_data(self, arg_0: List[float]) -> None:
		"""SCPI: ARBitrary:BLOCk:DATA \n
		Snippet: driver.arbitrary.block.set_data(arg_0 = [1.1, 2.2, 3.3]) \n
		Define the data points for a whole block. \n
			:param arg_0: Voltage and current settings depending on the instrument type. If the interpolation mode is sets to 1, it indicates that the mode is activated. If the interpolation mode is sets to 0, it indicates that the mode is not activated.
		"""
		param = Conversions.list_to_csv_str(arg_0)
		self._core.io.write(f'ARBitrary:BLOCk:DATA {param}')

	def get_repetitions(self) -> int:
		"""SCPI: ARBitrary:BLOCk:REPetitions \n
		Snippet: value: int = driver.arbitrary.block.get_repetitions() \n
		Sets or queries the number of repetitions of the block of arbitrary data. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('ARBitrary:BLOCk:REPetitions?')
		return Conversions.str_to_int(response)

	def set_repetitions(self, arg_0: int) -> None:
		"""SCPI: ARBitrary:BLOCk:REPetitions \n
		Snippet: driver.arbitrary.block.set_repetitions(arg_0 = 1) \n
		Sets or queries the number of repetitions of the block of arbitrary data. \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'ARBitrary:BLOCk:REPetitions {param}')

	def get_endpoint(self) -> int:
		"""SCPI: ARBitrary:BLOCk:ENDPoint \n
		Snippet: value: int = driver.arbitrary.block.get_endpoint() \n
		Queries the number of data points of the block of arbitrary data. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('ARBitrary:BLOCk:ENDPoint?')
		return Conversions.str_to_int(response)

	def clear(self) -> None:
		"""SCPI: ARBitrary:BLOCk:CLEar \n
		Snippet: driver.arbitrary.block.clear() \n
		Clears a file selected for the block under channel arbitrary settings. See also method RsNgx.Arbitrary.Block.value. \n
		"""
		self._core.io.write(f'ARBitrary:BLOCk:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ARBitrary:BLOCk:CLEar \n
		Snippet: driver.arbitrary.block.clear_with_opc() \n
		Clears a file selected for the block under channel arbitrary settings. See also method RsNgx.Arbitrary.Block.value. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ARBitrary:BLOCk:CLEar', opc_timeout_ms)

	def get_value(self) -> int:
		"""SCPI: ARBitrary:BLOCk \n
		Snippet: value: int = driver.arbitrary.block.get_value() \n
		Select individual block between 1 to 8 in an arbitrary sequence. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('ARBitrary:BLOCk?')
		return Conversions.str_to_int(response)

	def set_value(self, arg_0: int) -> None:
		"""SCPI: ARBitrary:BLOCk \n
		Snippet: driver.arbitrary.block.set_value(arg_0 = 1) \n
		Select individual block between 1 to 8 in an arbitrary sequence. \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'ARBitrary:BLOCk {param}')



from enum import Enum


# noinspection SpellCheckingInspection
class ArbEndBehavior(Enum):
	"""2 Members, HOLD ... OFF"""
	HOLD = 0
	OFF = 1


# noinspection SpellCheckingInspection
class ArbTrigMode(Enum):
	"""2 Members, RUN ... SINGle"""
	RUN = 0
	SINGle = 1


# noinspection SpellCheckingInspection
class CalibrationType(Enum):
	"""4 Members, CURR ... VOLT"""
	CURR = 0
	IMP = 1
	NCUR = 2
	VOLT = 3


# noinspection SpellCheckingInspection
class DefaultStep(Enum):
	"""2 Members, DEF ... DEFault"""
	DEF = 0
	DEFault = 1


# noinspection SpellCheckingInspection
class DioFaultSource(Enum):
	"""6 Members, CC ... SINK"""
	CC = 0
	CR = 1
	CV = 2
	OUTPut = 3
	PROTection = 4
	SINK = 5


# noinspection SpellCheckingInspection
class DioOutSource(Enum):
	"""3 Members, FORCed ... TRIGger"""
	FORCed = 0
	OUTPut = 1
	TRIGger = 2


# noinspection SpellCheckingInspection
class DioSignal(Enum):
	"""2 Members, CONStant ... PULSe"""
	CONStant = 0
	PULSe = 1


# noinspection SpellCheckingInspection
class FastLogSampleRate(Enum):
	"""6 Members, S001k ... S500k"""
	S001k = 0
	S010k = 1
	S050k = 2
	S100 = 3
	S250k = 4
	S500k = 5


# noinspection SpellCheckingInspection
class FastLogTarget(Enum):
	"""2 Members, SCPI ... USB"""
	SCPI = 0
	USB = 1


# noinspection SpellCheckingInspection
class Filename(Enum):
	"""3 Members, DEF ... INT"""
	DEF = 0
	EXT = 1
	INT = 2


# noinspection SpellCheckingInspection
class HcpyFormat(Enum):
	"""2 Members, BMP ... PNG"""
	BMP = 0
	PNG = 1


# noinspection SpellCheckingInspection
class LogMode(Enum):
	"""4 Members, COUNt ... UNLimited"""
	COUNt = 0
	DURation = 1
	SPAN = 2
	UNLimited = 3


# noinspection SpellCheckingInspection
class LowHigh(Enum):
	"""2 Members, HIGH ... LOW"""
	HIGH = 0
	LOW = 1


# noinspection SpellCheckingInspection
class MinOrMax(Enum):
	"""4 Members, MAX ... MINimum"""
	MAX = 0
	MAXimum = 1
	MIN = 2
	MINimum = 3


# noinspection SpellCheckingInspection
class PrioMode(Enum):
	"""2 Members, CPM ... VPM"""
	CPM = 0
	VPM = 1


# noinspection SpellCheckingInspection
class TriggerChannel(Enum):
	"""6 Members, ALL ... NONE"""
	ALL = 0
	CH1 = 1
	CH2 = 2
	CH3 = 3
	CH4 = 4
	NONE = 5


# noinspection SpellCheckingInspection
class TriggerCondition(Enum):
	"""19 Members, ANINput ... VMODe"""
	ANINput = 0
	ARB = 1
	ARBGroup = 2
	ARBPoint = 3
	CMODe = 4
	ENABle = 5
	FUSE = 6
	ILEVel = 7
	INHibit = 8
	LOG = 9
	OPP = 10
	OTP = 11
	OUTPut = 12
	OVP = 13
	PLEVel = 14
	RAMP = 15
	STATistics = 16
	VLEVel = 17
	VMODe = 18


# noinspection SpellCheckingInspection
class TriggerDioSource(Enum):
	"""2 Members, EXT ... IN"""
	EXT = 0
	IN = 1


# noinspection SpellCheckingInspection
class TriggerDirection(Enum):
	"""2 Members, INPut ... OUTPut"""
	INPut = 0
	OUTPut = 1


# noinspection SpellCheckingInspection
class TriggerOperMode(Enum):
	"""5 Members, CC ... SINK"""
	CC = 0
	CR = 1
	CV = 2
	PROTection = 3
	SINK = 4


# noinspection SpellCheckingInspection
class TriggerSource(Enum):
	"""3 Members, DIO ... OUTPut"""
	DIO = 0
	OMODe = 1
	OUTPut = 2


# noinspection SpellCheckingInspection
class UsbClass(Enum):
	"""2 Members, CDC ... TMC"""
	CDC = 0
	TMC = 1



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Group:
	"""Group commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("group", core, parent)

	def get_state(self) -> int or bool:
		"""SCPI: ARBitrary:TRIGgered:GROup[:STATe] \n
		Snippet: value: int or bool = driver.arbitrary.triggered.group.get_state() \n
		Sets or queries the trigger condition of the arbitrary step group for the selected channel. \n
			:return: arg_0: (integer or boolean) No help available
		"""
		response = self._core.io.query_str('ARBitrary:TRIGgered:GROup:STATe?')
		return Conversions.str_to_int_or_bool(response)

	def set_state(self, arg_0: int or bool) -> None:
		"""SCPI: ARBitrary:TRIGgered:GROup[:STATe] \n
		Snippet: driver.arbitrary.triggered.group.set_state(arg_0 = 1) \n
		Sets or queries the trigger condition of the arbitrary step group for the selected channel. \n
			:param arg_0: (integer or boolean)
				- OFF: There is no DIO pin that has a mode set to arbitrary step group for the selected channel.
				- 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8: DIO pin/s are enabled with a mode set to arbitrary step group for the selected channel.When DIO pin is enabled with arbitrary step point mode, QuickArb function will step to the next point when the correct voltage is applied to the DIO pin."""
		param = Conversions.decimal_or_bool_value_to_str(arg_0)
		self._core.io.write(f'ARBitrary:TRIGgered:GROup:STATe {param}')
